@@ -1,5 +1,5 @@
 // 
-//  Copyright (C) 2009 andoni
+//  Copyright (C) 2009 Andoni Morales Alastruey
 // 
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -24,8 +24,10 @@ namespace LongoMatch.Video.Editor
 	
 	public enum VideoFormat
 	{
-		TV,
-		HD720p,
-		HD1080p
+		PORTABLE=0,
+		VGA=1,
+		TV=2,
+		HD720p=3,
+		HD1080p=4
 	}
 }
